<?php

namespace Litecms\Blog\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\Blog\Repositories\Eloquent\Filters\BlogPublicFilter;
use Litecms\Blog\Repositories\Eloquent\Presenters\BlogListPresenter;
use Litecms\Blog\Interfaces\BlogRepositoryInterface;

class BlogPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(BlogRepositoryInterface $blog)
    {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.blog.modules'), 'blog', guard_url('blog'));
        $this->repository = $blog;

    }

    /**
     * Show blog's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(BlogPublicFilter::class)
            ->setPresenter(BlogListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('blog::blog.names'))
            ->view('blog::public.blog.index')
            ->data(compact('data', 'meta', 'modules'))
            ->output();
    }


    /**
     * Show blog.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();
        $modules = $this->modules;

        return $this->response->setMetaTitle($data['name'] . trans('blog::blog.name'))
            ->view('blog::public.blog.show')
            ->data(compact('data', 'modules'))
            ->output();
    }

}
